DROP TABLE ACL_PERMISSION;
DROP TABLE ACL_OBJECT_IDENTITY;
DROP TABLE  PARTY CASCADE CONSTRAINTS;
DROP TABLE GROUP_ROLE CASCADE CONSTRAINTS;
DROP  TABLE PARTY_GROUP CASCADE CONSTRAINTS;
DROP TABLE PARTY_RELATIONSHIP CASCADE  CONSTRAINTS;
DROP TABLE PARTY_ROLE CASCADE CONSTRAINTS;
DROP TABLE ROLE  CASCADE CONSTRAINTS;
DROP TABLE USER_LOGIN CASCADE CONSTRAINTS;

CREATE TABLE acl_object_identity (
	id NUMBER PRIMARY  KEY,
	object_identity VARCHAR2(250) NOT NULL,
	parent_object  INTEGER,
	acl_class VARCHAR2(250) NOT NULL,
	CONSTRAINT  unique_object_identity UNIQUE(object_identity),
	FOREIGN KEY (parent_object)  REFERENCES acl_object_identity(id)
);

CREATE TABLE acl_permission (
	id NUMBER PRIMARY  KEY,
	acl_object_identity NUMBER NOT NULL,
	recipient VARCHAR2(100) NOT  NULL,
	mask NUMBER NOT NULL,
	CONSTRAINT unique_recipient  UNIQUE(acl_object_identity, recipient),
	FOREIGN KEY (acl_object_identity)  REFERENCES acl_object_identity(id)
);

CREATE TABLE PARTY (
	PARTY_ID NUMBER NOT NULL,
	PARTY_TYPE_ID  NUMBER,
	EXTERNAL_ID VARCHAR2(20),
	CREATED_DATE  VARCHAR2(255),
	CREATED_BY_USER_LOGIN VARCHAR2(255),
	LAST_MODIFIED_DATE  VARCHAR2(255),
	LAST_MODIFIED_BY_USER_LOGIN  VARCHAR2(255),
	LAST_UPDATED_STAMP VARCHAR2(255),
	LAST_UPDATED_TX_STAMP  VARCHAR2(255),
	CREATED_STAMP VARCHAR2(255),
	CREATED_TX_STAMP  VARCHAR2(255),
	CONSTRAINT PK_PARTY_ID UNIQUE(PARTY_ID)
);

CREATE TABLE PARTY_GROUP (
	PARTY_ID NUMBER NOT NULL,
	GROUP_PARENT_ID  NUMBER NULL,
	GROUP_NAME VARCHAR2(255) NOT NULL,
	CONSTRAINT PK_PARTY_GROUP  UNIQUE(PARTY_ID)
);

CREATE TABLE PARTY_RELATIONSHIP (
	PARTY_ID_FROM NUMBER NOT  NULL,
	PARTY_ID_TO NUMBER NOT NULL,
	TYPE NUMBER NULL,
	CONSTRAINT  PK_PARTY_RELATIONSHIP UNIQUE(PARTY_ID_FROM, PARTY_ID_TO),
	FOREIGN KEY  (PARTY_ID_FROM) REFERENCES PARTY(PARTY_ID),
	FOREIGN KEY (PARTY_ID_TO)  REFERENCES PARTY(PARTY_ID)
);

CREATE TABLE ROLE (
	ROLE_ID NUMBER NOT NULL,
	ROLE_ID_PARENT  NUMBER,
	ROLE_NAME VARCHAR2(50) NOT NULL,
	ROLE_DESCRIPTION  VARCHAR2(255),
	CONSTRAINT PK_ROLE UNIQUE(ROLE_ID),
	FOREIGN KEY  (ROLE_ID_PARENT) REFERENCES ROLE(ROLE_ID)
);

CREATE TABLE USER_LOGIN (
	USER_LOGIN_ID VARCHAR2(50) NOT  NULL,
	PARTY_ID NUMBER NOT NULL,
	PASSWORD VARCHAR2(50) NOT  NULL,
	CONSTRAINT PK_USER_LOGIN UNIQUE(USER_LOGIN_ID),
	FOREIGN KEY  (PARTY_ID) REFERENCES PARTY_GROUP(PARTY_ID)
);

CREATE TABLE PARTY_ROLE (
	USER_LOGIN_ID VARCHAR2(50) NOT NULL,
	ROLE_ID  NUMBER NOT NULL,
	CONSTRAINT PK_PARTY_ROLE UNIQUE(USER_LOGIN_ID,  ROLE_ID),
	FOREIGN KEY (USER_LOGIN_ID) REFERENCES  USER_LOGIN(USER_LOGIN_ID),
	FOREIGN KEY (ROLE_ID) REFERENCES  ROLE(ROLE_ID)
);

CREATE TABLE GROUP_ROLE (
	PARTY_ID NUMBER NOT NULL,
	ROLE_ID NUMBER NOT  NULL,
	CONSTRAINT PK_GROUP_ROLE UNIQUE(PARTY_ID, ROLE_ID),
	FOREIGN KEY  (PARTY_ID) REFERENCES PARTY_GROUP(PARTY_ID),
	FOREIGN KEY (ROLE_ID) REFERENCES  ROLE(ROLE_ID)
);
