package net.gencat.ctti.canigo.exempleCrudAmbFiltre.bo;

import java.util.List;

import net.gencat.ctti.canigo.exempleCrudAmbFiltre.excepcions.NoPotCanviarPoblacioException;
import net.gencat.ctti.canigo.exempleCrudAmbFiltre.excepcions.PoblacioJaExisteixALaComarcaException;
import net.gencat.ctti.canigo.exempleCrudAmbFiltre.model.Comarca;
import net.gencat.ctti.canigo.exempleCrudAmbFiltre.model.Poblacio;
import net.gencat.ctti.canigo.services.persistence.UniversalHibernateDAO;

import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

/**
 * =======================================================================
 * OT Canig
 * 
 * Implementaci de la interficie PoblacioBO.
 * 
 * ========================================================================
 */

@Transactional(readOnly=true,propagation=Propagation.SUPPORTS)
public class PoblacioBOImpl implements PoblacioBO {
	
	private UniversalHibernateDAO hibernateDAO;
	
	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public void delete(Poblacio poblacio) {
		// TODO cal fer el refresh?
		hibernateDAO.refresh(poblacio);
		hibernateDAO.delete(poblacio);
	}
	
	@SuppressWarnings("unchecked")
	public List<Poblacio> getAllPoblacions() {
		return (List<Poblacio>)hibernateDAO.findAll(Poblacio.class);
	}
	
	@Transactional(readOnly=true,propagation=Propagation.SUPPORTS)
	public Poblacio getPoblacio(Long poblacioKey) {
		return (Poblacio) hibernateDAO.get(Poblacio.class, poblacioKey);
	}
	
	@SuppressWarnings("unchecked")
	public List<Comarca> getAllComarques() {
		return (List<Comarca>)hibernateDAO.findAll(Comarca.class);
	}
	
	public Comarca getComarca(Long comarcaKey) {
		return (Comarca)hibernateDAO.get(Comarca.class, comarcaKey);
	}

	public void refresh(Poblacio poblacio) {
		hibernateDAO.refresh(poblacio);
	}
	
	public void refresh(Comarca comarca) {
		hibernateDAO.refresh(comarca);
	}

	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public void addPoblacio(Comarca comarca, Poblacio poblacio) throws PoblacioJaExisteixALaComarcaException {
		//if(poblacio.getId()!=null) {
		List<Poblacio> poblacions = comarca.getPoblacions();
		for (Poblacio poblacio2 : poblacions) {
			if(poblacio.getNomPoblacio().equalsIgnoreCase(poblacio2.getNomPoblacio()) && 
				comarca.equals(poblacio2.getComarca())) {
				throw new PoblacioJaExisteixALaComarcaException();
			}
		}
		//}
		hibernateDAO.refresh(comarca);
		comarca.addPoblacio(poblacio);
		hibernateDAO.saveOrUpdate(comarca);
	}
	
	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public Poblacio updatePoblacio(Poblacio poblacio) throws NoPotCanviarPoblacioException {
		Poblacio boundLinia = (Poblacio) hibernateDAO.getHibernateSession().load(Poblacio.class, poblacio.getId());
		if(poblacio.getComarca()==null || poblacio.getComarca().getId()==null){
			poblacio.setComarca(boundLinia.getComarca());
		}
		else{
			if(!poblacio.getComarca().getId().equals(boundLinia.getComarca().getId())) {
				throw new NoPotCanviarPoblacioException();
			}
		}
		Poblacio merged = (Poblacio) hibernateDAO.getHibernateSession().merge(poblacio);
		hibernateDAO.update(merged);
		return poblacio;
	}

	/**
	 * @return the hibernateDAO
	 */
	public UniversalHibernateDAO getHibernateDAO() {
		return hibernateDAO;
	}

	/**
	 * @param hibernateDAO the hibernateDAO to set
	 */
	public void setHibernateDAO(UniversalHibernateDAO hibernateDAO) {
		this.hibernateDAO = hibernateDAO;
	}

}
