package net.gencat.ctti.canigo.exempleMestreDetall.bo;

import java.util.List;

import net.gencat.ctti.canigo.exempleMestreDetall.model.Factura;
import net.gencat.ctti.canigo.exempleMestreDetall.model.Linia;
import net.gencat.ctti.canigo.services.persistence.UniversalHibernateDAO;

import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

/**
 * Implementaci de la interfcie @FacturaBO
 * @author OTCanigo
 *
 */
@Transactional(readOnly=true,propagation=Propagation.SUPPORTS)
public class FacturaBOImpl implements FacturaBO {

	private UniversalHibernateDAO hibernateDAO;
	
	public UniversalHibernateDAO getHibernateDAO() {
		return hibernateDAO;
	}

	public void setHibernateDAO(UniversalHibernateDAO hibernateDAO) {
		this.hibernateDAO = hibernateDAO;
	}

	@SuppressWarnings("unchecked")
	public List<Factura> getAllFactures() {
		return (List<Factura>)hibernateDAO.findAll(Factura.class);
	}

	@Transactional(readOnly=true,propagation=Propagation.SUPPORTS)
	public Factura getFactura(Long facturaKey) {
		return (Factura) hibernateDAO.get(Factura.class, facturaKey);
	}
	
	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public void save(Factura factura) {
		if(factura.getId()!=null){
			Factura oldFactura = getFactura(factura.getId());
			if(oldFactura.getLinies()!=null && factura.getLinies()==null){
				factura.setLinies(oldFactura.getLinies());
			}
			hibernateDAO.getHibernateSession().merge(factura);
		}
		else{
			hibernateDAO.saveOrUpdate(factura);
		}
	}

	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public void delete(final Factura factura) {
		hibernateDAO.delete(factura);
	}

	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public void addLinia(Factura factura, Linia linia) throws LiniaJaExisteixALaFacturaException {
		if(linia.getId()!=null) {
			List<Linia> linies = factura.getLinies();
			for (Linia linia2 : linies) {
				if(linia.getId().equals(linia2.getId())) {
					throw new LiniaJaExisteixALaFacturaException();
				}
			}
		}
		hibernateDAO.refresh(factura);
		factura.addLinia(linia);
		hibernateDAO.saveOrUpdate(factura);
	}
	
	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public Linia updateLinia(Linia linia) throws NoPotCanviarFacturaException {
		Linia boundLinia = (Linia) hibernateDAO.getHibernateSession().load(Linia.class, linia.getId());
		if(linia.getFactura()==null || linia.getFactura().getId()==null){
			linia.setFactura(boundLinia.getFactura());
		}
		else{
			if(!linia.getFactura().getId().equals(boundLinia.getFactura().getId())) {
				throw new NoPotCanviarFacturaException();
			}
		}
		Linia merged = (Linia) hibernateDAO.getHibernateSession().merge(linia);
		hibernateDAO.update(merged);
		return linia;
	}
	
	@Transactional(readOnly=false,propagation=Propagation.SUPPORTS)
	public void deleteLinia(Linia currentLinia) {
		currentLinia.getFactura().removeLinia(currentLinia);
		hibernateDAO.delete(currentLinia);
	}
	
	@Transactional(readOnly=true,propagation=Propagation.SUPPORTS)
	public Linia getLinia(Long liniaKey){
		return (Linia) hibernateDAO.get(Linia.class, liniaKey);
	}
}
