package net.gencat.ctti.canigo.exempleMestreDetall.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;

/**
 * =======================================================================
 * OT Canig
 * 
 * Aquesta classe s una entitat persistent.
 * T com a atributs un identificador (PK) i altres caracterstiques, i 
 * est associat a l'entitat Linia amb relaci 1:N
 * ========================================================================
 *
 */

@Entity
@NamedQueries( {
	@NamedQuery(name = "Factura.readPopulated", query = "SELECT DISTINCT factura FROM Factura factura "
			+ " LEFT JOIN FETCH factura.linies AS linia"
			+ " WHERE factura.id=?1"),
	@NamedQuery(name = "Factura.findFacturaNumbered", query = "SELECT o FROM Factura o  WHERE  o.numFactura = ?1") })
public class Factura implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	private Long id;

	private String numFactura;
	private String nomClient;
	private long telefon;

	@OneToMany(mappedBy = "factura", cascade = CascadeType.ALL)
	private List<Linia> linies = null;

	/**
	 * @return the linies
	 */
	public List<Linia> getLinies() {
		return linies;
	}

	public void addLinia(Linia linia) {
		linia.setFactura(this);
		if (null == this.linies) {
			this.linies = new ArrayList<Linia>();
		}
		this.linies.add(linia);
	}

	public void removeLinia(Linia linia) {
		linia.setFactura(null);
		linies.remove(linia);
	}

	public void setLinies(List<Linia> linies) {
		this.linies = linies;
	}

	/**
	 * @return the id
	 */
	public Long getId() {
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(Long id) {
		this.id = id;
	}

	/**
	 * @return the numFactura
	 */
	public String getNumFactura() {
		return numFactura;
	}

	/**
	 * @param numFactura the numFactura to set
	 */
	public void setNumFactura(String numFactura) {
		this.numFactura = numFactura;
	}

	/**
	 * @return the nomClient
	 */
	public String getNomClient() {
		return nomClient;
	}

	/**
	 * @param nomClient the nomClient to set
	 */
	public void setNomClient(String nomClient) {
		this.nomClient = nomClient;
	}

	/**
	 * @return the telefon
	 */
	public long getTelefon() {
		return telefon;
	}

	/**
	 * @param telefon the telefon to set
	 */
	public void setTelefon(long telefon) {
		this.telefon = telefon;
	}

	@Override
	public boolean equals(Object arg0) {
		if (arg0 == null) {
			return false;
		}
		if (arg0 instanceof Factura) {
			Factura otherFactura = (Factura) arg0;
			return otherFactura.getId().equals(this.getId());
		}
		return super.equals(arg0);
	}

	@Override
	public int hashCode() {
		return this.id.hashCode();
	}

	public String toString() {
		return numFactura;
	}
}
